# Uriorcurie

a URI or a CURIE

URI: http://www.w3.org/2001/XMLSchema#anyURI

* [base](https://w3id.org/linkml/base): URIorCURIE


* [repr](https://w3id.org/linkml/repr): str




## Identifier and Mapping Information


